<?php
// ----------------------------------------------------------------------
// eNvolution Content Management System
// Copyright (C) 2002 by the eNvolution Development Team.
// http://www.envolution.com/
// ----------------------------------------------------------------------
// Based on:
// Postnuke Content Management System - www.postnuke.com
// PHP-NUKE Web Portal System - http://phpnuke.org/
// Thatware - http://thatware.org/
// ----------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
//
// 
// ----------------------------------------------------------------------
// POST-NUKE Content Management System
// Copyright (C) 2002 by the PostNuke Development Team.
// http://www.postnuke.com/
// ----------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WIthOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------
// Original Author of file: Stefan Koehler
// Purpose of file:  RteMulti administration API
// ----------------------------------------------------------------------

/**
 * create a new RTE activation
 * @param $args['editortype'] which editor for use
 * @param $args['modname'] module-name for activation
 * @param $args['varname'] TEXTAREA-name (or: 'form' for FORM-Tag)
 * @param $args['keystring'] Searchstring (complete beginning FORM- or TEXTAREA-Tag, or any text-string)
 * @param $args['newstring'] New string (not neccassary for FORM- or TEXTAREA-Tag, or replacement of 'keystring')
 * @param $args['comment'] Comments (just for info)
 * @returns int
 * @return rtemulti-ID on success, false on failure
 */
function rtemulti_adminapi_create($args)
{

    // Get arguments from argument array
    extract($args);

    // Optional arguments
    if (!isset($comment)) {
        $comment = '';
    }

    // Argument check - make sure that all required arguments are present,
    // if not then set an appropriate error message and return
    if (!isset($modname)) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'RteMulti::', "$modname::", ACCESS_ADD)) {
        pnSessionSetVar('errormsg', _RTEMULTINOAUTH);
        return false;
    }

    // Get datbase setup
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    $rtemultitable = $pntable['rtemulti'];
    $rtemulticolumn = &$pntable['rtemulti_column'];

    // Get next ID in table
    $nextId = $dbconn->GenId($rtemultitable);

    // Add item
    $sql = "INSERT INTO $rtemultitable (
              $rtemulticolumn[rid],
              $rtemulticolumn[editortype],
              $rtemulticolumn[modname],
              $rtemulticolumn[varname],
              $rtemulticolumn[keystring],
              $rtemulticolumn[newstring],
              $rtemulticolumn[comment])
            VALUES (
              $nextId,
              '" . pnVarPrepForStore($editortype) . "',
              '" . pnVarPrepForStore($modname) . "',
              '" . pnVarPrepForStore($varname) . "',
              '" . pnVarPrepForStore($keystring) . "',
              '" . pnVarPrepForStore($newstring) . "',
              '" . pnVarPrepForStore($comment) . "')";
    $dbconn->Execute($sql);

    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _RTEMULTILINKCREATEFAILED);
        return false;
    }

    // Get the ID of the item that we inserted
    $rid = $dbconn->PO_Insert_ID($rtemultitable, $rtemulticolumn['rid']);

    // Let any hooks know that we have created a new link
    pnModCallHooks('item', 'create', $rid, 'rid');

    // Return the id of the newly created link to the calling process
    return $rid;
}

/**
 * delete an RTE activation
 * @param $args['rid'] ID of the link
 * @returns bool
 * @return true on success, false on failure
 */
function rtemulti_adminapi_delete($args)
{
    // Get arguments from argument array
    extract($args);

    // Argument check
    if (!isset($rid)) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Load API
    if (!pnModAPILoad('rtemulti', 'user')) {
        $output->Text(_LOADFAILED);
        return $output->GetOutput();
    }

    // The user API function is called
    $link = pnModAPIFunc('rtemulti',
                         'user',
                         'get',
                         array('rid' => $rid));

    if ($link == false) {
        $output->Text(_RTEMULTINOSUCHLINK);
        return $output->GetOutput();
    }

    // Security check
    if (!pnSecAuthAction(0, 'RteMulti::', "$link[modname]::$rid", ACCESS_DELETE)) {
        pnSessionSetVar('errormsg', _RTEMULTINOAUTH);
        return false;
    }

    // Get datbase setup
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    $rtemultitable = $pntable['rtemulti'];
    $rtemulticolumn = &$pntable['rtemulti_column'];

    // Delete the item
    $sql = "DELETE FROM $rtemultitable
            WHERE $rtemulticolumn[rid] = " . pnVarPrepForStore($rid);
    $dbconn->Execute($sql);

    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _RTEMULTIDELETEFAILED);
        return false;
    }

    // Let any hooks know that we have deleted a link
    pnModCallHooks('item', 'delete', $rid, '');

    // Let the calling process know that we have finished successfully
    return true;
}

/**
 * update an RTE activation
 * @param $args['editortype'] which editor for use
 * @param $args['modname'] module-name for activation
 * @param $args['varname'] TEXTAREA-name (or: 'form' for FORM-Tag)
 * @param $args['keystring'] Searchstring (complete beginning FORM- or TEXTAREA-Tag, or any text-string)
 * @param $args['newstring'] New string (not neccassary for FORM- or TEXTAREA-Tag, or replacement of 'keystring')
 * @param $args['comment'] Comments (just for info)
 * @returns bool
 * @return true on success, false on failure
 */
function rtemulti_adminapi_update($args)
{
    // Get arguments from argument array
    extract($args);

    if (!isset($comment)) {
        $comment = '';
    }
    // Argument check
    if ((!isset($rid)) ||
        (!isset($modname))) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Load API
    if (!pnModAPILoad('rtemulti', 'user')) {
        $output->Text(_LOADFAILED);
        return $output->GetOutput();
    }

    // The user API function is called
    $link = pnModAPIFunc('rtemulti',
                         'user',
                         'get',
                         array('rid' => $rid));

    if ($link == false) {
        $output->Text(_RTEMULTINOSUCHLINK);
        return $output->GetOutput();
    }

    if (!pnSecAuthAction(0, 'RteMulti::', "$link[modname]::$rid", ACCESS_EDIT)) {
        pnSessionSetVar('errormsg', _RTEMULTINOAUTH);
        return false;
    }
    if (!pnSecAuthAction(0, 'RteMulti::', "$modname::$rid", ACCESS_EDIT)) {
        pnSessionSetVar('errormsg', _RTEMULTINOAUTH);
        return false;
    }

    // Get database setup
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    $rtemultitable = $pntable['rtemulti'];
    $rtemulticolumn = &$pntable['rtemulti_column'];

    // Update the link
    $sql = "UPDATE $rtemultitable
            SET $rtemulticolumn[editortype] = '" . pnVarPrepForStore($editortype) . "',
                $rtemulticolumn[modname] = '" . pnVarPrepForStore($modname) . "',
                $rtemulticolumn[varname] = '" . pnVarPrepForStore($varname) . "',
                $rtemulticolumn[keystring] = '" . pnVarPrepForStore($keystring) . "',
                $rtemulticolumn[newstring] = '" . pnVarPrepForStore($newstring) . "',
                $rtemulticolumn[comment] = '" . pnVarPrepForStore($comment) . "'
            WHERE $rtemulticolumn[rid] = " . pnVarPrepForStore($rid);
    $dbconn->Execute($sql);

    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _RTEMULTIUPDATEFAILED);
        return false;
    }

    // Let the calling process know that we have finished successfully
    return true;
}
?>